@@ -1,4 +1,4 @@
-make clisp-module CC="${CC}" CFLAGS="${CFLAGS}" INCLUDES="$absolute_linkkitdir"
+make clisp-module CC="${CC}" CPPFLAGS="${CPPFLAGS}" CFLAGS="${CFLAGS}" INCLUDES="$absolute_linkkitdir"
 NEW_FILES=''
 NEW_LIBS=''
 NEW_MODULES=''
