@@ -3,7 +3,7 @@
 ;; <http://www.lisp.org/HyperSpec/Body/sec_6-1.html>
 ;; <http://www.lisp.org/HyperSpec/Body/mac_loop.html>
 ;; Bruno Haible 1991-2002
-;; Sam Steingold 1999-2002
+;; Sam Steingold 1999-2004
 
 (in-package "COMMON-LISP")
 (export '(loop loop-finish))
@@ -809,6 +809,7 @@
                                             :requires-stepbefore seen-endtest))))))))
                                 (t
                                  (unless (symbolp pattern) (loop-syntax-error kw))
+                                 (unless pattern (setq pattern (gensym)))
                                  ;; ANSI CL 6.1.2.1.1 implies that the
                                  ;; start/end/by clauses can come in any
                                  ;; order, but only one of each kind.
@@ -942,7 +943,13 @@
       (unless (null results)
         (push `(RETURN-FROM ,block-name ,@results) finally-code))
       ; Initialisierungen abarbeiten und optimieren:
-      (let ((initializations1 nil))
+      (let ((initializations1
+             (unless (zerop (length *helpvars*))
+               ;; `*helpvars*' must be bound first thing
+               (list (make-loop-init
+                      :specform 'LET
+                      :bindings
+                      (map 'list #'(lambda (var) `(,var NIL)) *helpvars*))))))
         ; `depends-preceding' backpropagation:
         (let ((later-depend nil))
           (dolist (initialization initializations)
@@ -1008,13 +1015,11 @@
            (make-loop-init
             :specform 'LET
             :bindings
-            `(,@(map 'list #'(lambda (var) `(,var NIL)) *helpvars*)
-                ,@(mapcar #'(lambda (var) (check-accu-var var) `(,var NIL))
-                          (delete-duplicates accu-vars-nil))
-                ,@(mapcar #'(lambda (var) (check-accu-var (car var)) var)
-                          (delete-duplicates accu-vars-0 :key #'car)))
-            :declspecs
-            (nreverse accu-declarations))
+            `(,@(mapcar #'(lambda (var) (check-accu-var var) `(,var NIL))
+                        (delete-duplicates accu-vars-nil))
+              ,@(mapcar #'(lambda (var) (check-accu-var (car var)) var)
+                        (delete-duplicates accu-vars-0 :key #'car)))
+            :declspecs (nreverse accu-declarations))
            initializations1))
         ;; Remove the NIL placeholders in stepafter-code.
         (setq stepafter-code (delete 'NIL stepafter-code))
